@@ -20,4 +20,5 @@ class EntryFieldService(ApiMethods):
     def get_all(self, attributeId: int, displayType: DisplayType):
 
         api_url = f'/api/services/app/EntryField/GetAll?AttribteId={attributeId}&DisplayType={displayType.value}'
-        return self.get_data(url=api_url, request=request)
+        response = self.get_data(url=api_url, request=request)
+        return super()._get_entries_response(response)
